@@ -21,7 +21,7 @@
 compute spherical harmonics tranforms on them.
 """
 
-import warnings
+import logging
 
 from .version import __version__
 
@@ -41,6 +41,8 @@ from .pixelfunc import (
     npix2nside,
     nside2order,
     order2nside,
+    order2npix,
+    npix2order,
     isnsideok,
     isnpixok,
     ring2nest,
@@ -79,14 +81,14 @@ from .sphtfunc import (
     bl2beam,
     beam2bl,
     check_max_nside,
+    map2alm_spin,
+    alm2map_spin,
 )
 
 from ._query_disc import query_disc, query_strip, query_polygon, boundaries
 from ._pixelfunc import ringinfo, pix2ring
 
 from ._sphtools import rotate_alm
-from ._sphtools import alm2map_spin_healpy as alm2map_spin
-from ._sphtools import map2alm_spin_healpy as map2alm_spin
 from .rotator import Rotator, vec2dir, dir2vec
 from ._healpy_pixel_lib import UNSEEN
 from .visufunc import (
@@ -107,16 +109,25 @@ from ._masktools import dist2holes_healpy as dist2holes
 from ._hotspots import hotspots_healpy as hotspots
 from ._line_integral_convolution import line_integral_convolution
 
+from .newvisufunc import projview, newprojplot
 
+
+from astropy.utils.decorators import deprecated
+
+
+@deprecated("1.15.0")
 def disable_warnings():
-    """Disable all healpy warnings messages for the current session
+    """healpy uses logging now
 
-    Warnings from individual functions can be disabled setting
-    ``verbose=False``.
-    Warnings can be re-enabled calling ``hp.enable_warnings()``.
+    This function has no effect
     """
-    warnings.filterwarnings(action="ignore", module="healpy")
+    pass
 
 
+@deprecated("1.15.0")
 def enable_warnings():
-    warnings.simplefilter("always")
\ No newline at end of file
+    """healpy uses logging now
+
+    This function has no effect
+    """
+    pass
