@@ -9,7 +9,7 @@ def is_seq(o):
     ----------
     o : any object
       The object to check
-    
+
     Returns
     -------
     is_seq : bool, scalar
@@ -18,7 +18,7 @@ def is_seq(o):
     return hasattr(o, "__len__")
 
 
-def is_seq_of_seq(o):
+def is_seq_of_seq(o, allow_none=False):
     """Check if the object is a sequence of sequences. No check is done on
     the sizes of the sequences.
 
@@ -26,7 +26,9 @@ def is_seq_of_seq(o):
     ----------
     o : any object
       The object to check
-    
+    allow_none : bool, optional
+      Treat ``None`` entries as sequence.
+
     Returns
     -------
     is_seq_of_seq : bool
@@ -36,6 +38,8 @@ def is_seq_of_seq(o):
         return False
     for s in o:
         if not is_seq(s):
+            if allow_none and s is None:
+                continue
             return False
     return True
 
@@ -47,7 +51,7 @@ def is_like2d(o):
     ----------
     o : any object
       The object to check
-   
+
     Returns
     -------
     is_like2d : bool, scalar
@@ -68,7 +72,7 @@ def is_like2d(o):
 
 def len_array_or_arrays(o):
     """Returns the length of a single array or list of arrays
-    
+
     Parameters
     ----------
     o : either array or sequence of arrays
