@@ -21,19 +21,21 @@
 """
 from __future__ import division
 
-import six
 import sys
-import warnings
+import logging
 
-if sys.version >= "3.4":
-    import pathlib
+log = logging.getLogger("healpy")
+
+import pathlib
 import astropy.io.fits as pf
 import numpy as np
+from astropy.utils.decorators import deprecated_renamed_argument
 
 from . import pixelfunc
 from .sphtfunc import Alm
 from .pixelfunc import UNSEEN
 from . import cookbook as cb
+from astropy.utils.decorators import deprecated
 
 standard_column_names = {
     1: "TEMPERATURE",
@@ -42,11 +44,10 @@ standard_column_names = {
     6: ["II", "IQ", "IU", "QQ", "QU", "UU"],
 }
 
-allowed_paths = tuple(six.string_types)
-if sys.version >= "3.4":
-    allowed_paths += (pathlib.Path,)
+allowed_paths = (str, pathlib.Path)
 
 
+@deprecated(since="1.15.0")
 class HealpixFitsWarning(Warning):
     pass
 
@@ -89,21 +90,15 @@ def write_cl(filename, cl, dtype=None, overwrite=False):
       the cl array to write to file
     dtype : np.dtype (optional)
       The datatype in which the columns will be stored. If not supplied,
-      np.float64 will be assumed.
-      (WARNING: in some future version, the type of cl will be used instead.)
+      the dtype of the input cl will be used. This changed in `healpy` 1.15.0,
+      in previous versions, cl by default were saved in `float64`.
     overwrite : bool, optional
       If True, existing file is silently overwritten. Otherwise trying to write
-      an existing file raises an OSError (IOError for Python 2).
+      an existing file raises an OSError.
     """
     if dtype is None:
-        warnings.warn(
-            "The default dtype of write_cl() will change in a future version: "
-            "explicitly set the dtype if it is important to you",
-            category=FutureWarning,
-        )
-        dtype = np.float64
-        # At some poin change this to:
-        # dtype = cl.dtype if isinstance(cl, np.ndarray) else cl[0].dtype
+        dtype = cl.dtype if isinstance(cl, np.ndarray) else cl[0].dtype
+
     # check the dtype and convert it
     fitsformat = getformat(dtype)
     column_names = ["TEMPERATURE", "GRADIENT", "CURL", "G-T", "C-T", "C-G"]
@@ -139,7 +134,13 @@ def write_map(
     extra_header=(),
     overwrite=False,
 ):
-    """Writes a healpix map into a healpix file.
+    """Writes a healpix map into a healpix FITS file.
+
+    .. warning::
+    Starting from healpy 1.15.0, if you do not specify `dtype`,
+    the map will be written to disk with the same precision it is stored in memory.
+    Previously, by default `healpy` wrote maps in `float32`.
+    To reproduce the same behaviour of `healpy` 1.14.0 and below, set `dtype=np.float32`.
 
     Parameters
     ----------
@@ -178,9 +179,10 @@ def write_map(
       The datatype in which the columns will be stored. Will be converted
       internally from the numpy datatype to the fits convention. If a list,
       the length must correspond to the number of map arrays.
-      Default: use np.float32
-      (WARNING: in a future version this will change to
-      "use the data type of the input array(s)".)
+      Default: use the data type of the input array(s)
+      .. note::
+      this changed in 1.15.0, previous versions saved in float32
+      by default
     overwrite : bool, optional
       If True, existing file is silently overwritten. Otherwise trying to write
       an existing file raises an OSError (IOError for Python 2).
@@ -194,14 +196,8 @@ def write_map(
 
     # check the dtype and convert it
     if dtype is None:
-        warnings.warn(
-            "The default dtype of write_map() will change in a future version: "
-            "explicitly set the dtype if it is important to you",
-            category=FutureWarning,
-        )
-        dtype = [np.float32 for x in m]
-        # Change this at some point to:
-        # dtype = [x.dtype for x in m]
+        dtype = [x.dtype for x in m]
+        log.warning("setting the output map dtype to %s" % str(dtype))
     try:
         fitsformat = []
         for curr_dtype in dtype:
@@ -217,7 +213,7 @@ def write_map(
     else:
         assert len(column_names) == len(m), "Length column_names != number of maps"
 
-    if column_units is None or isinstance(column_units, six.string_types):
+    if column_units is None or isinstance(column_units, str):
         column_units = [column_units] * len(m)
 
     # maps must have same length
@@ -301,10 +297,11 @@ def write_map(
     tbhdu.writeto(str(filename), overwrite=overwrite)
 
 
+@deprecated_renamed_argument("verbose", None, "1.15.0")
 def read_map(
     filename,
     field=0,
-    dtype=np.float64,
+    dtype=None,
     nest=False,
     partial=False,
     hdu=1,
@@ -315,6 +312,13 @@ def read_map(
     """Read a healpix map from a fits file.  Partial-sky files,
     if properly identified, are expanded to full size and filled with UNSEEN.
 
+    .. warning::
+    Starting from healpy 1.15.0, if you do not specify `dtype`,
+    the map will be read in memory with the same precision it is stored on disk.
+    Previously, by default `healpy` wrote maps in `float32` and then upcast to
+    `float64` when reading to memory. To reproduce the same behaviour of `healpy`
+    1.14.0 and below, set `dtype=np.float64` in `read_map`.
+
     Parameters
     ----------
     filename : str or HDU or HDUList or pathlib.Path instance
@@ -331,9 +335,7 @@ def read_map(
       types for each field. In that case, the length of the list must
       correspond to the length of the field parameter.
       If None, keep the dtype of the input FITS file
-      Default: use np.float64
-      (WARNING: in a future version this will change to
-      "use the data type of the input FITS file".)
+      Default: Preserve the data types in the file
     nest : bool, optional
       If True return the map in NEST ordering, otherwise in RING ordering;
       use fits keyword ORDERING to decide whether conversion is needed or not
@@ -351,9 +353,8 @@ def read_map(
       the header number to look at (start at 0)
     h : bool, optional
       If True, return also the header. Default: False.
-    verbose : bool, optional
-      If True, print a number of diagnostic messages, call hp.disable_warnings() to
-      disable warnings for all functions.
+    verbose : bool, deprecated
+      It has no effect
     memmap : bool, optional
       Argument passed to astropy.io.fits.open, if True, the map is not read into memory,
       but only the required pixels are read when needed. Default: False.
@@ -363,15 +364,6 @@ def read_map(
     m | (m0, m1, ...) [, header] : array or a tuple of arrays, optionally with header appended
       The map(s) read from the file, and the header if *h* is True.
     """
-    # Temporary warning for default dtype
-    if dtype == np.float64:
-        warnings.warn(
-            "If you are not specifying the input dtype and using the default "
-            "np.float64 dtype of read_map(), please consider that it will "
-            "change in a future version to None as to keep the same dtype of "
-            "the input file: please explicitly set the dtype if it is "
-            "important to you."
-        )
 
     opened_file = False
     if isinstance(filename, allowed_paths):
@@ -381,29 +373,27 @@ def read_map(
     fits_hdu = _get_hdu(filename, hdu=hdu, memmap=memmap)
 
     nside = fits_hdu.header.get("NSIDE")
-    if nside is None and verbose:
-        warnings.warn(
-            "No NSIDE in the header file : will use length of array", HealpixFitsWarning
-        )
+    if nside is None:
+        log.info("No NSIDE in the header file : will use length of array")
+        pix = fits_hdu.data.field(0)
+        nside = pixelfunc.npix2nside(pix.size)
     else:
         nside = int(nside)
-    if verbose:
-        warnings.warn("NSIDE = {0:d}".format(nside))
+    log.info("NSIDE = %d", nside)
 
     if not pixelfunc.isnsideok(nside):
         raise ValueError("Wrong nside parameter.")
     ordering = fits_hdu.header.get("ORDERING", "UNDEF").strip()
     if ordering == "UNDEF":
         ordering = nest and "NESTED" or "RING"
-        warnings.warn("No ORDERING keyword in header file : " "assume %s" % ordering)
-    if verbose:
-        warnings.warn("ORDERING = {0:s} in fits file".format(ordering))
+        log.info("No ORDERING keyword in header file : assume %s", ordering)
+    log.info("ORDERING = %s in fits file", ordering)
 
     sz = pixelfunc.nside2npix(nside)
     ret = []
 
     # partial sky: check OBJECT, then INDXSCHM
-    obj = fits_hdu.header.get("OBJECT", "UNDEF").strip()
+    obj = str(fits_hdu.header.get("OBJECT", "UNDEF")).strip()
     if obj != "UNDEF":
         if obj == "PARTIAL":
             partial = True
@@ -423,9 +413,8 @@ def read_map(
 
     if schm == "UNDEF":
         schm = partial and "EXPLICIT" or "IMPLICIT"
-        warnings.warn("No INDXSCHM keyword in header file : " "assume {}".format(schm))
-    if verbose:
-        warnings.warn("INDXSCHM = {0:s}".format(schm))
+        log.info("No INDXSCHM keyword in header file: assume %s", schm)
+    log.info("INDXSCHM = %s", schm)
 
     if field is None:
         field = range(len(fits_hdu.data.columns) - 1 * partial)
@@ -438,8 +427,8 @@ def read_map(
         try:
             pix = fits_hdu.data.field(0).astype(int, copy=False).ravel()
         except pf.VerifyError as e:
-            warnings.warn(e)
-            warnings.warn("Trying to fix a badly formatted header")
+            log.warning(e)
+            log.warning("Trying to fix a badly formatted header")
             fits_hdu.verify("fix")
             pix = fits_hdu.data.field(0).astype(int, copy=False).ravel()
 
@@ -457,8 +446,8 @@ def read_map(
             else:
                 m = fits_hdu.data.field(ff).astype(curr_dtype, copy=False).ravel()
         except pf.VerifyError as e:
-            warnings.warn(e)
-            warnings.warn("Trying to fix a badly formatted header")
+            log.warning(e)
+            log.warning("Trying to fix a badly formatted header")
             m = fits_hdu.verify("fix")
             if curr_dtype is None:
                 m = fits_hdu.data.field(ff).ravel()
@@ -470,20 +459,18 @@ def read_map(
             mnew[pix] = m
             m = mnew
 
-        if (not pixelfunc.isnpixok(m.size) or (sz > 0 and sz != m.size)) and verbose:
-            warnings.warn("nside={0:d}, sz={1:d}, m.size={2:d}".format(nside, sz, m.size))
+        if not pixelfunc.isnpixok(m.size) or (sz > 0 and sz != m.size):
+            log.warning("nside={0:d}, sz={1:d}, m.size={2:d}".format(nside, sz, m.size))
             raise ValueError("Wrong nside parameter.")
         if not nest is None:  # no conversion with None
             if nest and ordering == "RING":
                 idx = pixelfunc.nest2ring(nside, np.arange(m.size, dtype=np.int32))
                 m = m[idx]
-                if verbose:
-                    warnings.warn("Ordering converted to NEST")
+                log.info("Ordering converted to NEST")
             elif (not nest) and ordering == "NESTED":
                 idx = pixelfunc.ring2nest(nside, np.arange(m.size, dtype=np.int32))
                 m = m[idx]
-                if verbose:
-                    warnings.warn("Ordering converted to RING")
+                log.info("Ordering converted to RING")
         try:
             m[pixelfunc.mask_bad(m)] = UNSEEN
         except OverflowError:
@@ -636,7 +623,7 @@ def read_alm(filename, hdu=1, return_mmax=False):
 
     for unit in np.atleast_1d(hdu):
         idx, almr, almi = [_get_hdu(filename, hdu=unit).data.field(i) for i in range(3)]
-        l = np.floor(np.sqrt(idx - 1)).astype(np.long)
+        l = np.floor(np.sqrt(idx - 1)).astype(int)
         m = idx - l ** 2 - l - 1
         if (m < 0).any():
             raise ValueError("Negative m value encountered !")
@@ -721,7 +708,7 @@ def getformat(t):
       The FITS string code describing the data type, or None if unknown type.
     """
     conv = {
-        np.dtype(np.bool): "L",
+        np.dtype(np.bool_): "L",
         np.dtype(np.uint8): "B",
         np.dtype(np.int16): "I",
         np.dtype(np.int32): "J",
@@ -767,3 +754,19 @@ def getformat(t):
             return "A%d" % (l)
     except:
         pass
+    try:
+        if np.dtype(t.type) in conv:
+            return conv[np.dtype(t.type)]
+    except:
+        pass
+    try:
+        if np.dtype(t[0].type) in conv:
+            return conv[np.dtype(t[0].type)]
+    except:
+        pass
+
+    raise ValueError(
+        "healpy could not understand the equivalent FITS datatype of {}, please open an issue on the healpy Github repository".format(
+            str(t)
+        )
+    )
