@@ -17,11 +17,13 @@
 #
 #  For more information about Healpy, see http://code.google.com/p/healpy
 #
-import warnings
+import logging
+
+log = logging.getLogger("healpy")
 import numpy as np
-import six
 
 import astropy.io.fits as pf
+from astropy.utils.decorators import deprecated_renamed_argument
 from scipy.integrate import trapz
 from astropy.utils import data
 
@@ -37,6 +39,9 @@ from . import pixelfunc
 
 from .pixelfunc import maptype, UNSEEN, ma_to_array, accept_ma
 
+from ._sphtools import alm2map_spin_healpy as alm2map_spin
+from ._sphtools import map2alm_spin_healpy as map2alm_spin
+
 
 class FutureChangeWarning(UserWarning):
     pass
@@ -71,6 +76,9 @@ def anafast(
     remove monopole from the map before running `anafast` to reduce
     boundary effects.
 
+    For recommendations about how to set `lmax`, `iter`, and weights, see the
+    `Anafast documentation <https://healpix.sourceforge.io/html/fac_anafast.htm>`
+
     Parameters
     ----------
     map1 : float, array-like shape (Npix,) or (3, Npix)
@@ -153,6 +161,7 @@ def anafast(
         return cls
 
 
+@deprecated_renamed_argument("verbose", None, "1.15.0")
 def map2alm(
     maps,
     lmax=None,
@@ -168,6 +177,8 @@ def map2alm(
     """Computes the alm of a Healpix map. The input maps must all be
     in ring ordering.
 
+    For recommendations about how to set `lmax`, `iter`, and weights, see the
+    `Anafast documentation <https://healpix.sourceforge.io/html/fac_anafast.htm>`
 
     Pixel values are weighted before applying the transform:
 
@@ -212,7 +223,7 @@ def map2alm(
     use_pixel_weights: bool, optional
       If True, use pixel by pixel weighting, healpy will automatically download the weights, if needed
     verbose : bool, optional
-      If True prints diagnostic information. Default: True
+      Deprecated, has not effect.
 
     Returns
     -------
@@ -239,10 +250,7 @@ def map2alm(
         if datapath is not None:
             pixel_weights_filename = os.path.join(datapath, filename)
             if os.path.exists(pixel_weights_filename):
-                if verbose:
-                    warnings.warn(
-                        "Accessing pixel weights from {}".format(pixel_weights_filename)
-                    )
+                log.info("Accessing pixel weights from %s", pixel_weights_filename)
             else:
                 raise RuntimeError(
                     "You specified datapath but pixel weights file"
@@ -285,6 +293,7 @@ def map2alm(
     return np.array(alms)
 
 
+@deprecated_renamed_argument("verbose", None, "1.15.0")
 def alm2map(
     alms,
     nside,
@@ -350,7 +359,7 @@ def alm2map(
     check_max_nside(nside)
 
     alms = smoothalm(
-        alms, fwhm=fwhm, sigma=sigma, pol=pol, inplace=inplace, verbose=verbose
+        alms, fwhm=fwhm, sigma=sigma, pol=pol, inplace=inplace
     )
 
     if not cb.is_seq_of_seq(alms):
@@ -388,6 +397,7 @@ def alm2map(
         return np.array(output)
 
 
+@deprecated_renamed_argument("verbose", None, "1.15.0")
 def synalm(cls, lmax=None, mmax=None, new=False, verbose=True):
     """Generate a set of alm given cl.
     The cl are given as a float array. Corresponding alm are generated.
@@ -419,28 +429,13 @@ def synalm(cls, lmax=None, mmax=None, new=False, verbose=True):
 
     Notes
     -----
-    The order of the spectra will change in a future release. The new= parameter
-    help to make the transition smoother. You can start using the new order
-    by setting new=True.
-    In the next version of healpy, the default will be new=True.
-    This change is done for consistency between the different tools
-    (alm2cl, synfast, anafast).
-    In the new order, the spectra are ordered by diagonal of the correlation
-    matrix. Eg, if fields are T, E, B, the spectra are TT, EE, BB, TE, EB, TB
-    with new=True, and TT, TE, TB, EE, EB, BB if new=False.
+    We don't plan to change the default order anymore, that would break old
+    code in a way difficult to debug.
     """
-    if (not new) and verbose:
-        warnings.warn(
-            "The order of the input cl's will change in a future "
-            "release.\n"
-            "Use new=True keyword to start using the new order.\n"
-            "See documentation of healpy.synalm.",
-            category=FutureChangeWarning,
-        )
     if not cb.is_seq(cls):
         raise TypeError("cls must be an array or a sequence of arrays")
 
-    if not cb.is_seq_of_seq(cls):
+    if not cb.is_seq_of_seq(cls, True):
         # Only one spectrum
         if lmax is None or lmax < 0:
             lmax = cls.size - 1
@@ -457,7 +452,7 @@ def synalm(cls, lmax=None, mmax=None, new=False, verbose=True):
 
     # From here, we interpret cls as a list of spectra
     cls_list = list(cls)
-    maxsize = max([len(c) for c in cls])
+    maxsize = max([len(c) for c in cls if c is not None])
 
     if lmax is None or lmax < 0:
         lmax = maxsize - 1
@@ -481,7 +476,7 @@ def synalm(cls, lmax=None, mmax=None, new=False, verbose=True):
 
     szalm = Alm.getsize(lmax, mmax)
     alms_list = []
-    for i in six.moves.xrange(Nspec):
+    for i in range(Nspec):
         alm = np.zeros(szalm, "D")
         alm.real = np.random.standard_normal(szalm)
         alm.imag = np.random.standard_normal(szalm)
@@ -497,6 +492,7 @@ def synalm(cls, lmax=None, mmax=None, new=False, verbose=True):
     return np.array(alms_list)
 
 
+@deprecated_renamed_argument("verbose", None, "1.15.0")
 def synfast(
     cls,
     nside,
@@ -512,6 +508,9 @@ def synfast(
 ):
     """Create a map(s) from cl(s).
 
+    You can choose a random seed using `numpy.random.seed(SEEDVALUE)`
+    before calling `synfast`.
+
     Parameters
     ----------
     cls : array or tuple of array
@@ -538,6 +537,11 @@ def synfast(
     sigma : float, scalar, optional
       The sigma of the Gaussian used to smooth the map (applied on alm)
       [in radians]
+    new : bool, optional
+      If True, use the new ordering of cl's, ie by diagonal
+      (e.g. TT, EE, BB, TE, EB, TB or TT, EE, BB, TE if 4 cl as input).
+      If False, use the old ordering, ie by row
+      (e.g. TT, TE, TB, EE, EB, BB or TT, TE, EE, BB if 4 cl as input).
 
     Returns
     -------
@@ -548,15 +552,8 @@ def synfast(
 
     Notes
     -----
-    The order of the spectra will change in a future release. The new= parameter
-    help to make the transition smoother. You can start using the new order
-    by setting new=True.
-    In the next version of healpy, the default will be new=True.
-    This change is done for consistency between the different tools
-    (alm2cl, synfast, anafast).
-    In the new order, the spectra are ordered by diagonal of the correlation
-    matrix. Eg, if fields are T, E, B, the spectra are TT, EE, BB, TE, EB, TB
-    with new=True, and TT, TE, TB, EE, EB, BB if new=False.
+    We don't plan to change the default order anymore, that would break old
+    code in a way difficult to debug.
     """
     if not pixelfunc.isnsideok(nside):
         raise ValueError("Wrong nside value (must be a power of two).")
@@ -565,7 +562,7 @@ def synfast(
     cls_lmax = cb.len_array_or_arrays(cls) - 1
     if lmax is None or lmax < 0:
         lmax = min(cls_lmax, 3 * nside - 1)
-    alms = synalm(cls, lmax=lmax, mmax=mmax, new=new, verbose=verbose)
+    alms = synalm(cls, lmax=lmax, mmax=mmax, new=new)
     maps = alm2map(
         alms,
         nside,
@@ -576,7 +573,6 @@ def synfast(
         fwhm=fwhm,
         sigma=sigma,
         inplace=True,
-        verbose=verbose,
     )
     if alm:
         return np.array(maps), np.array(alms)
@@ -630,7 +626,7 @@ class Alm(object):
 
     @staticmethod
     def getidx(lmax, l, m):
-        """Returns index corresponding to (l,m) in an array describing alm up to lmax.
+        r"""Returns index corresponding to (l,m) in an array describing alm up to lmax.
 
         In HEALPix C++ and healpy, :math:`a_{lm}` coefficients are stored ordered by
         :math:`m`. I.e. if :math:`\ell_{max}` is 16, the first 16 elements are
@@ -767,6 +763,7 @@ def almxfl(alm, fl, mmax=None, inplace=False):
     return almout
 
 
+@deprecated_renamed_argument("verbose", None, "1.15.0")
 def smoothalm(
     alms,
     fwhm=0.0,
@@ -804,8 +801,7 @@ def smoothalm(
       If True, the alm's are modified inplace if they are contiguous arrays
       of type complex128. Otherwise, a copy of alm is made. Default: True.
     verbose : bool, optional
-      If True prints diagnostic information. Default: True
-      Call hp.disable_warnings() to disable warnings for all functions.
+      Deprecated, has not effect.
 
     Returns
     -------
@@ -817,20 +813,12 @@ def smoothalm(
     if (sigma is None) & (beam_window is None):
         sigma = fwhm / (2.0 * np.sqrt(2.0 * np.log(2.0)))
 
-    if verbose:
-        if beam_window is None:
-            warnings.warn(
-                "Sigma is {0:f} arcmin ({1:f} rad) ".format(
-                    sigma * 60 * 180 / np.pi, sigma
-                )
-            )
-            warnings.warn(
-                "-> fwhm is {0:f} arcmin".format(
-                    sigma * 60 * 180 / np.pi * (2.0 * np.sqrt(2.0 * np.log(2.0)))
-                )
-            )
-        else:
-            warnings.warn("Using provided beam window function")
+    if beam_window is None:
+        log.info("Sigma is %f arcmin (%f rad) ", sigma * 60 * 180 / np.pi, sigma)
+        log.info(
+            "-> fwhm is %f arcmin",
+            sigma * 60 * 180 / np.pi * (2.0 * np.sqrt(2.0 * np.log(2.0)))
+        )
 
     # Check alms
     if not cb.is_seq(alms):
@@ -871,7 +859,7 @@ def smoothalm(
     if lonely:
         return retalm[0]
     # case 2: 2d input, check if in-place smoothing for all alm's
-    for i in six.moves.xrange(len(alms)):
+    for i in range(len(alms)):
         samearray = alms[i] is retalm[i]
         if not samearray:
             # Case 2a:
@@ -884,6 +872,7 @@ def smoothalm(
     return alms
 
 
+@deprecated_renamed_argument("verbose", None, "1.15.0")
 @accept_ma
 def smoothing(
     map_in,
@@ -898,6 +887,7 @@ def smoothing(
     use_pixel_weights=False,
     datapath=None,
     verbose=True,
+    nest=False,
 ):
     """Smooth a map with a Gaussian symmetric beam.
 
@@ -935,7 +925,12 @@ def smoothing(
     datapath : None or str, optional
       If given, the directory where to find the weights data.
     verbose : bool, optional
-      If True prints diagnostic information. Default: True
+      Deprecated, has not effect.
+    nest : bool, optional
+      If True, the input map ordering is assumed to be NESTED. Default: False (RING)
+      This function will temporary reorder the NESTED map into RING to perform the
+      smoothing and order the output back to NESTED. If the map is in RING ordering
+      no internal reordering will be performed.
 
     Returns
     -------
@@ -958,6 +953,9 @@ def smoothing(
 
     check_max_nside(nside)
 
+    if nest:
+        map_in = pixelfunc.reorder(map_in, inp=None, out=None, r2n=None, n2r=True)
+
     if pol or n_maps in (0, 1):
         # Treat the maps together (1 or 3 maps)
         alms = map2alm(
@@ -977,11 +975,15 @@ def smoothing(
             beam_window=beam_window,
             pol=pol,
             mmax=mmax,
-            verbose=verbose,
             inplace=True,
         )
         output_map = alm2map(
-            alms, nside, lmax=lmax, mmax=mmax, pixwin=False, verbose=verbose, pol=pol,
+            alms,
+            nside,
+            lmax=lmax,
+            mmax=mmax,
+            pixwin=False,
+            pol=pol,
         )
     else:
         # Treat each map independently (any number)
@@ -1003,12 +1005,16 @@ def smoothing(
                 sigma=sigma,
                 beam_window=beam_window,
                 inplace=True,
-                verbose=verbose,
             )
-            output_map.append(alm2map(alm, nside, pixwin=False, verbose=verbose))
+            output_map.append(alm2map(alm, nside, pixwin=False))
         output_map = np.array(output_map)
     output_map[masks] = UNSEEN
 
+    if nest:
+        output_map = pixelfunc.reorder(
+            output_map, inp=None, out=None, r2n=True, n2r=False
+        )
+
     return output_map
 
 
@@ -1022,7 +1028,7 @@ def pixwin(nside, pol=False, lmax=None):
     pol : bool, optional
       If True, return also the polar pixel window. Default: False
     lmax : int, optional
-        Maximum l of the power spectrum (default: 3*nside-1) 
+        Maximum l of the power spectrum (default: 3*nside-1)
 
     Returns
     -------
@@ -1052,27 +1058,27 @@ def pixwin(nside, pol=False, lmax=None):
 def alm2map_der1(alm, nside, lmax=None, mmax=None):
     """Computes a Healpix map and its first derivatives given the alm.
 
-   The alm are given as a complex array. You can specify lmax
-   and mmax, or they will be computed from array size (assuming
-   lmax==mmax).
+    The alm are given as a complex array. You can specify lmax
+    and mmax, or they will be computed from array size (assuming
+    lmax==mmax).
 
-   Parameters
-   ----------
-   alm : array, complex
-     A complex array of alm. Size must be of the form mmax(lmax-mmax+1)/2+lmax
-   nside : int
-     The nside of the output map.
-   lmax : None or int, optional
-     Explicitly define lmax (needed if mmax!=lmax)
-   mmax : None or int, optional
-     Explicitly define mmax (needed if mmax!=lmax)
+    Parameters
+    ----------
+    alm : array, complex
+      A complex array of alm. Size must be of the form mmax(lmax-mmax+1)/2+lmax
+    nside : int
+      The nside of the output map.
+    lmax : None or int, optional
+      Explicitly define lmax (needed if mmax!=lmax)
+    mmax : None or int, optional
+      Explicitly define mmax (needed if mmax!=lmax)
 
-   Returns
-   -------
-   m, d_theta, d_phi : tuple of arrays
-     The maps correponding to alm, and its derivatives with respect to
-     theta and phi. d_phi is already divided by sin(theta)
-   """
+    Returns
+    -------
+    m, d_theta, d_phi : tuple of arrays
+      The maps correponding to alm, and its derivatives with respect to
+      theta and phi. d_phi is already divided by sin(theta)
+    """
     check_max_nside(nside)
     if lmax is None:
         lmax = -1
@@ -1089,8 +1095,8 @@ def new_to_old_spectra_order(cls_new_order):
     if Nspec < 0:
         raise ValueError("Input must be a list of n(n+1)/2 arrays")
     cls_old_order = []
-    for i in six.moves.xrange(Nspec):
-        for j in six.moves.xrange(i, Nspec):
+    for i in range(Nspec):
+        for j in range(i, Nspec):
             p = j - i
             q = i
             idx_new = p * (2 * Nspec + 1 - p) // 2 + q
@@ -1164,7 +1170,7 @@ def gauss_beam(fwhm, lmax=512, pol=False):
 
 
 def bl2beam(bl, theta):
-    """Computes a circular beam profile b(theta) in real space from 
+    """Computes a circular beam profile b(theta) in real space from
     its transfer (or window) function b(l) in spherical harmonic space.
 
     Parameters
@@ -1189,7 +1195,7 @@ def bl2beam(bl, theta):
 
     beam = bl[0] * p0 + bl[1] * p1 * 3
 
-    for l in np.arange(2, lmax):
+    for l in np.arange(2, lmax + 1):
         p2 = x * p1 * (2 * l - 1) / l - p0 * (l - 1) / l
         p0 = p1
         p1 = p2
@@ -1201,8 +1207,8 @@ def bl2beam(bl, theta):
 
 
 def beam2bl(beam, theta, lmax):
-    """Computes a transfer (or window) function b(l) in spherical 
-    harmonic space from its circular beam profile b(theta) in real 
+    """Computes a transfer (or window) function b(l) in spherical
+    harmonic space from its circular beam profile b(theta) in real
     space.
 
     Parameters
@@ -1210,7 +1216,7 @@ def beam2bl(beam, theta, lmax):
     beam : array
         Circular beam profile b(theta).
     theta : array
-        Radius at which the beam profile is given. Has to be given 
+        Radius at which the beam profile is given. Has to be given
         in radians with same size as beam.
     lmax : integer
         Maximum multipole moment at which to compute b(l).
@@ -1224,7 +1230,7 @@ def beam2bl(beam, theta, lmax):
     nx = len(theta)
     nb = len(beam)
     if nb != nx:
-        warnings.warn("beam and theta must have same size!")
+        raise ValueError("Beam and theta must have same size!")
 
     x = np.cos(theta)
     st = np.sin(theta)
