@@ -3,6 +3,7 @@ import os
 import numpy as np
 from copy import deepcopy
 from itertools import chain
+import pytest
 
 import unittest
 
@@ -42,7 +43,7 @@ class TestSphtFunc(unittest.TestCase):
                 "data",
                 "wmap_temperature_analysis_mask_r9_7yr_v4_udgraded32.fits",
             )
-        ).astype(np.bool)
+        ).astype(np.bool_)
         for m in chain(self.map1, self.map2):
             m.mask = np.logical_not(self.mask)
         self.cla = hp.read_cl(
@@ -276,7 +277,7 @@ class TestSphtFunc(unittest.TestCase):
         """rotate_alm also support rotation matrix instead of angles"""
         lmax = 32
         nalm = hp.Alm.getsize(lmax)
-        alm = np.zeros([3, nalm], dtype=np.complex)
+        alm = np.zeros([3, nalm], dtype=complex)
         alm[0, 1] = 1
         alm[1, 2] = 1
         alm_rotated_angles = alm.copy()
@@ -290,7 +291,7 @@ class TestSphtFunc(unittest.TestCase):
         # Test rotate_alm against the Fortran library
         lmax = 64
         nalm = hp.Alm.getsize(lmax)
-        alm = np.zeros([3, nalm], dtype=np.complex)
+        alm = np.zeros([3, nalm], dtype=complex)
         for i in range(3):
             for ell in range(lmax + 1):
                 for m in range(ell):
@@ -433,6 +434,12 @@ class TestSphtFunc(unittest.TestCase):
         with self.assertRaises(AssertionError):
             hp.Alm.getlm(500, 125751)
 
+    def test_rotate_alm_complex64(self):
+        lmax = 32
+        nalm = hp.Alm.getsize(lmax)
+        alm = np.zeros([3, nalm], dtype=np.complex64)
+        with pytest.raises(ValueError):
+            hp.rotate_alm(alm, 0.1, 0.2, 0.3)
 
 if __name__ == "__main__":
     unittest.main()
